@@ -19,17 +19,17 @@
  */
 
 using System;
-using Mono.Unix;
+using Mono.Addins;
 
 namespace GNOME {
 
 	class CurrentWindowScreenshotItem : ScreenshotItem {
 		public override string Name {
-			get { return Catalog.GetString ("Current window"); }
+			get { return AddinManager.CurrentLocalizer.GetString ("Current window"); }
 		}
 		
 		public override string Description {
-			get { return Catalog.GetString ("Take a screenshot of the current window."); }
+			get { return AddinManager.CurrentLocalizer.GetString ("Take a screenshot of the current window."); }
 		}
 		
 		public override string Icon {
