@@ -21,7 +21,7 @@ using System;
 using System.Linq;
 using System.Collections.Generic;
 
-using Mono.Unix;
+using Mono.Addins;
 
 using Do.Universe;
 using Do.Platform;
@@ -31,25 +31,18 @@ namespace PidginPlugin
 
 	public class PidginSetStatusAction : Act
 	{
-		IEnumerable<Item> statuses;
+
 
 		public PidginSetStatusAction ()
 		{
-			statuses = new [] {
-				new PidginStatusTypeItem (1), 
-				new PidginStatusTypeItem (2),
-				new PidginStatusTypeItem (3),
-				new PidginStatusTypeItem (4),
-				new PidginStatusTypeItem (5),
-			};
 		}
 
 		public override string Name {
-			get { return Catalog.GetString ("Set status"); }
+			get { return AddinManager.CurrentLocalizer.GetString ("Set status"); }
 		}
 
 		public override string Description {
-			get { return Catalog.GetString ("Set pidgin status message"); }
+			get { return AddinManager.CurrentLocalizer.GetString ("Set pidgin status message"); }
 		}
 
 		public override string Icon {
@@ -58,13 +51,17 @@ namespace PidginPlugin
 
 		public override IEnumerable<Type> SupportedItemTypes {
 			get {
-				yield return typeof (ITextItem);
+				yield return typeof (PidginStatusTypeItem);
 				yield return typeof (PidginSavedStatusItem);
+				yield return typeof (ITextItem);
 			}
 		}
 
 		public override IEnumerable<Type> SupportedModifierItemTypes {
-			get { yield return typeof (PidginStatusTypeItem); }
+			get { 
+				yield return typeof (ITextItem); 
+				yield return typeof (PidginStatusTypeItem);
+			}
 		}
 
 		public override bool ModifierItemsOptional {
@@ -73,31 +70,35 @@ namespace PidginPlugin
 
 		public override bool SupportsModifierItemForItems (IEnumerable<Item> items, Item modItem)
 		{
-			return items.First () is ITextItem;
-		}
-
-		public override IEnumerable<Item> DynamicModifierItemsForItem (Item item)
-		{
-			return statuses;
+			if (items.First () is PidginStatusTypeItem && modItem is ITextItem)
+				return true;
+			if (items.First () is ITextItem && modItem is PidginStatusTypeItem)
+				return true;
+			return false;
 		}
 
 		public override IEnumerable<Item> Perform (IEnumerable<Item> items, IEnumerable<Item> modItems)
 		{
 			int status;
-			string message;
+			string message = "";
 			try {
 				Pidgin.IPurpleObject prpl = Pidgin.GetPurpleObject ();
 
 				if (items.First () is PidginSavedStatusItem) {
 					status = (items.First () as PidginSavedStatusItem).ID;
 					prpl.PurpleSavedstatusActivate (status);
-				} else {
-					message = (items.First () as ITextItem).Text;
+				} else if (items.First () is PidginStatusTypeItem) {
+					status = (items.First () as PidginStatusTypeItem).Status;
 					if (modItems.Any ())
-						status = (int) (modItems.First () as PidginStatusTypeItem).Status;
+						message = (modItems.First () as ITextItem).Text;
+					Pidgin.PurpleSetAvailabilityStatus (status, message);
+				} else if (items.First () is ITextItem) {
+					if (modItems.Any ())
+						status = (modItems.First () as PidginStatusTypeItem).Status;
 					else
 						status = prpl.PurpleSavedstatusGetType (prpl.PurpleSavedstatusGetCurrent ());
-					Pidgin.PurpleSetAvailabilityStatus ((uint) status, message);
+					message = (items.First () as ITextItem).Text;
+					Pidgin.PurpleSetAvailabilityStatus (status, message);
 				}
 			} catch (Exception e) {
 				Log<PidginSetStatusAction>.Error ("Could not set Pidgin status: {0}", e.Message);
